@@ -1,4 +1,5 @@
 from add_on import AddOn
+from add_on_gateway import AddOnGateway
 from address import Address
 from address_gateway import AddressGateway
 from braintree_gateway import BraintreeGateway
@@ -10,11 +11,14 @@ from customer import Customer
 from customer_search import CustomerSearch
 from customer_gateway import CustomerGateway
 from discount import Discount
+from discount_gateway import DiscountGateway
 from descriptor import Descriptor
 from error_codes import ErrorCodes
 from error_result import ErrorResult
 from errors import Errors
 from environment import Environment
+from plan import Plan
+from plan_gateway import PlanGateway
 from resource_collection import ResourceCollection
 from search import Search
 from settlement_batch_summary import SettlementBatchSummary
